package com.suncreate.kafkaConsumerMonitor.service;

import kafka.admin.AdminClient;
import kafka.coordinator.group.GroupOverview;
import org.apache.kafka.clients.admin.AdminClientConfig;
import org.apache.kafka.common.TopicPartition;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import scala.collection.JavaConversions;

import javax.annotation.PostConstruct;
import java.util.*;

@Service
public class ConsumerGroupsService {
    private static final Logger log = LoggerFactory.getLogger(ConsumerGroupsService.class);

    @Value("${kafka.consumer.servers}")
    private String servers;

    private List<GroupOverview> groupListAll;

    @PostConstruct
    private void Init() {
        try {
            //身份认证
            System.setProperty("java.security.auth.login.config", "/home/server/import/conf/jaas.conf");
            System.setProperty("java.security.krb5.conf", "/home/server/import/conf/krb5.conf");
            //System.setProperty("java.security.auth.login.config", "D:/Project/shiny/kafka-consumer-monitor/conf/jaas.conf");
            //System.setProperty("java.security.krb5.conf", "D:/Project/shiny/kafka-consumer-monitor/conf/krb5.conf");

            Properties properties = new Properties();
            properties.put(AdminClientConfig.BOOTSTRAP_SERVERS_CONFIG, servers.replace("21005", "21007"));
            properties.put(AdminClientConfig.SECURITY_PROTOCOL_CONFIG, "SASL_PLAINTEXT");

            AdminClient client = AdminClient.create(properties);

            try {
                groupListAll = scala.collection.JavaConversions.seqAsJavaList(client.listAllGroupsFlattened().toSeq());

                if (groupListAll != null) {
                    log.info("ConsumerGroupsService Init 获取所有消费者组 成功 groupListAll size=" + groupListAll.size());
                } else {
                    log.error("ConsumerGroupsService Init 获取所有消费者组 失败 groupListAll=null");
                }
            } catch (Exception e) {
                log.error("ConsumerGroupsService Init 获取所有消费者组 失败", e);
            } finally {
                client.close();
            }
        } catch (Exception e) {
            log.error("ConsumerGroupsService Init 失败", e);
        }
    }

    public String getGroupId(String topic, String groupId) {
        java.util.Set<String> groups = getConsumerGroups(topic);

        for (String item : groups) {
            if (item.indexOf(groupId) >= 0) {
                return item;
            }
        }

        return groupId;
    }

    private java.util.Set<String> getConsumerGroups(String topic) {
        Properties properties = new Properties();
        properties.put(AdminClientConfig.BOOTSTRAP_SERVERS_CONFIG, servers.replace("21005", "21007"));
        properties.put(AdminClientConfig.SECURITY_PROTOCOL_CONFIG, "SASL_PLAINTEXT");

        AdminClient client = AdminClient.create(properties);

        java.util.Set<String> groups = new HashSet<String>();

        try {
            if (groupListAll != null) {
                for (GroupOverview overview : groupListAll) {
                    String groupID = overview.groupId();
                    Map<TopicPartition, Object> offsets = JavaConversions.mapAsJavaMap(client.listGroupOffsets(groupID));
                    for (TopicPartition partition : offsets.keySet()) {
                        if (partition.topic().equals(topic)) {
                            groups.add(groupID);
                        }
                    }
                }
            }

            log.info("Topic:" + topic + " 消费者组集合:" + groups);
        } catch (Exception e) {
            log.error("getConsumerGroups error", e);
        } finally {
            client.close();
        }

        return groups;
    }
}
