package com.suncreate.kafkaConsumerMonitor.service;

import java.text.SimpleDateFormat;
import java.util.Date;

import com.suncreate.kafkaConsumerMonitor.model.SendAlarmResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;
import org.springframework.web.client.RestTemplate;

import javax.annotation.Resource;

@Service
public class SendAlarmService {
    private static final Logger log = LoggerFactory.getLogger(SendAlarmService.class);

    @Resource
    private RestTemplate restTemplate;

    @Autowired
    private Log2ESService log2ESService;

    private final SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");

    @Value("${alarmUrl}")
    private String alarmUrl;

    public void Send(String alarmName, Date alarmTime) throws Exception {
        try {
            String url = alarmUrl + "?alarmName=" + alarmName + "&alarmTime=" + simpleDateFormat.format(alarmTime);
            ResponseEntity<SendAlarmResult> responseEntity = restTemplate.getForEntity(url, SendAlarmResult.class);
            SendAlarmResult result = responseEntity.getBody();
            if (result.getStatusString().equals("0")) {
                log2ESService.log2ES(true, "上报" + alarmName + "成功");
                log.info("上报" + alarmName + "成功");
            } else {
                log2ESService.log2ES(false, "上报" + alarmName + "失败，失败原因：" + result.getResultErrorMsg());
                log.info("上报" + alarmName + "失败，失败原因：" + result.getResultErrorMsg());
            }
        } catch (Exception e) {
            StringBuffer sb = new StringBuffer();
            sb.append("上报" + alarmName + "失败，失败原因：" + e.getMessage() + "\r\n");
            for (StackTraceElement stackTraceElement : e.getStackTrace()) {
                sb.append(stackTraceElement.toString() + "\r\n");
            }
            log2ESService.log2ES(false, sb.toString());
            log.error("SendAlarmService error", e);
        }
    }
}